@@ -4,8 +4,7 @@ use crossterm::{
     execute,
     terminal::{disable_raw_mode, enable_raw_mode, EnterAlternateScreen, LeaveAlternateScreen},
 };
-use gonk_core::{Bind, Colors, Database, Key, Modifier, Toml};
-use static_init::dynamic;
+use gonk_core::{Bind, Database, Key, Modifier, Toml};
 use std::io::{stdout, Stdout};
 use std::time::Duration;
 use std::time::Instant;
@@ -35,12 +34,6 @@ pub enum Mode {
     Options,
 }
 
-#[dynamic]
-static DB: Database = Database::default();
-
-#[dynamic]
-static COLORS: Colors = Toml::new().colors;
-
 const TICK_RATE: Duration = Duration::from_millis(100);
 const POLL_RATE: Duration = Duration::from_millis(4);
 const SEEK_TIME: f64 = 10.0;
@@ -74,10 +67,10 @@ impl App {
         Self {
             terminal,
             mode: Mode::Browser,
-            queue: Queue::new(toml.volume()),
+            queue: Queue::new(toml.volume(), toml.colors.clone()),
             browser: Browser::new(),
             options: Options::new(toml),
-            search: Search::new(),
+            search: Search::new(toml.colors.clone()),
             db: Database::default(),
         }
     }
